precision highp float;

uniform float		globalTime;
uniform float		amplitude;
uniform vec2		resolution;
uniform vec3		color;
uniform float		frequencies[128];

float RADIUS_MIN_1 = 11.0 * amplitude * 100.0;
float RADIUS_MAX_1 = 12.0 * amplitude * 100.0;

float RADIUS_MIN_2 = 5.2 * amplitude * 100.0;
float RADIUS_MAX_2 = 6.0 * amplitude * 100.0;

float RADIUS_MIN_3 = 2.5 * amplitude * 100.0;
float RADIUS_MAX_3 = 3.0 * amplitude * 100.0;

float RADIUS_MIN_4 = 1.1 * amplitude * 100.0;
float RADIUS_MAX_4 = 1.5 * amplitude * 100.0;

float RADIUS_MIN_5 = 0.4 * amplitude * 100.0;
float RADIUS_MAX_5 = 0.6 * amplitude * 100.0;

float				getFrequency(float angle)
{
	float	index = angle * 127.0;
	float	floorIndex = floor(index);
	float	diff = index - floorIndex;

	int		indexInf = int(floorIndex);
	int		indexSup = indexInf + 1;

	return mix(frequencies[indexInf], frequencies[indexSup], diff);
}

bool				draw(float vecLength, float value, float min, float max) {
	if (vecLength > min + value && vecLength < max + value)
	{
		vec3	colorDeg = vec3(1.0);

		float realMin = min;
        float realMax = max;

        if(min < (vecLength - value - 1.0))
        	realMin = min + float(int(min - vecLength + value + 1.0)) - 1.0;

		if(max > (vecLength - value))
			realMax = max - float(int(max - vecLength + value)) + 1.0;

		for(float i = realMin; i < realMax; i += 1.0) {
			if (vecLength > i + value && vecLength < (i + 1.0) + value)
			{
				float	intensity = (i - min) / (max - min);
				colorDeg -= vec3(intensity);
			}
		}
		gl_FragColor = vec4(colorDeg * color, 1.0);
		return true;
	}
	else
		return false;
}

void main(void)
{
	vec2	center = vec2(resolution.x / 2.0, resolution.y / 2.0);
	vec2	vecPix = center - gl_FragCoord.xy;
	vec2	normVecPix = normalize(vecPix);
	vec2	normVecRef = normalize(center - vec2(0.0, center.y));

	float	cosAngle = dot(normVecPix, normVecRef);
	float	angle = (degrees(acos(cosAngle)) + 90.0) / 360.0;
	float	value = getFrequency(angle);
	value = value * 100.0;


	float	vecLength = length(vecPix);

	if(draw(vecLength, value, RADIUS_MIN_5, RADIUS_MAX_5)) {
		return;
	}
	else if(draw(vecLength, value, RADIUS_MIN_4, RADIUS_MAX_4)) {
		return;
	}
	else if(draw(vecLength, value, RADIUS_MIN_3, RADIUS_MAX_3)) {
		return;
	}
	else if(draw(vecLength, value, RADIUS_MIN_2, RADIUS_MAX_2)) {
		return;
	}
	else if(draw(vecLength, value, RADIUS_MIN_1, RADIUS_MAX_1)) {
		return;
	}
	else
		gl_FragColor = vec4(0.0, 0.0, 0.0, 1.0);
}