precision highp float;

uniform float		globalTime;
uniform float		amplitude;
uniform vec2		resolution;
uniform vec3		color;
uniform float		frequencies[128];

float				getFrequencyX()
{
	float	index = (gl_FragCoord.x / resolution.x) * 127.0;
	float	floorIndex = floor(index);
	float	diff = index - floorIndex;
	
	int		indexInf = int(floorIndex);
	int		indexSup = indexInf + 1;
	
	return mix(frequencies[indexInf], frequencies[indexSup], diff);
}

float				getFrequencyY()
{
	float	index = (gl_FragCoord.y / resolution.y) * 127.0;
	float	floorIndex = floor(index);
	float	diff = index - floorIndex;

	int		indexInf = int(floorIndex);
	int		indexSup = indexInf + 1;

	return mix(frequencies[indexInf], frequencies[indexSup], diff);
}

void main(void)
{
	float	maxSize = max(resolution.x, resolution.y);
	vec2	center = vec2(resolution.x / 2.0, resolution.y / 2.0);
	float	dist = distance(gl_FragCoord.xy, center);
	float	frequencyX = getFrequencyX();
	float	frequencyY = getFrequencyY();

	float	radiusX = amplitude * maxSize * frequencyX;
	float	radiusY = amplitude * maxSize * frequencyY;

	float valueColor = 0.0;
	if (dist < radiusX)
	{
		float value = dist / radiusX;
		valueColor = (1.0 - value);
	}

	if (dist < radiusY)
	{
		float	value = dist / radiusY;
		valueColor = max(valueColor, (1.0 - value));
	}


	if(valueColor > 0.0)
	{
		gl_FragColor = vec4(valueColor * color.x, valueColor * color.y, valueColor * color.z, 1.0);
	}
	else {
		gl_FragColor = vec4(0.0, 0.0, 0.0, 1.0);
	}
}